@@ -4,9 +4,9 @@ void Generator::baseClassCode(ostream &out) const
 {
     key(out);
 
-    out << "d_requiredTokens__(" << d_options.requiredTokens() << ")\n"
+    out << "d_requiredTokens_(" << d_options.requiredTokens() << ")\n"
            "{\n";
 
     if (d_options.polymorphic())
-        out << "    Meta__::t_nErrors = &d_nErrors__;\n";
+        out << "    Meta_::t_nErrors = &d_nErrors_;\n";
 }   
