@@ -7,9 +7,11 @@ void Generator::idOfTag(ostream &out) const
     if (d_options.tagMismatches().value == Options::ON)
     {
         out << "char const *idOfTag_[] = {\n";
+
         for (auto const &poly: d_polymorphic)
             out << "    \"" << poly.first << "\",\n";
-        out <<     "    \"<undefined>\"\n"
+
+        out <<     "    \"EndPolyType_\"\n"
                "};\n";
     }
 }
