@@ -2,6 +2,6 @@
 
 void Generator::key(ostream &out) const
 {
-    out << setw(d_indent) << "" << "// $insert " << d_key << "\n" <<
+    out << setw(d_indent) << "" << "// $insert " << d_key << '\n' <<
             setw(d_indent) << "" << flush;
 }
