@@ -8,7 +8,7 @@
 
 class Grammar
 {
-    typedef std::set<Symbol const *> SymbolSet;
+    using SymbolSet = std::set<Symbol const *>;
 
     SymbolSet    d_derivable;           // used when testing whether the start
                                         // symbol derives any sentences
