@@ -1,6 +1,6 @@
 #include "item.ih"
 
-Item::Item(Item const *item, size_t/*unsigned*/ dot)
+Item::Item(Item const *item, size_t dot)
 :
     d_production(item->d_production),
     d_dot(dot)
