@@ -5,12 +5,12 @@ Next::Solution Next::solveByPrecedence(Symbol const *productionSymbol) const
     switch (Terminal::comparePrecedence(d_symbol, productionSymbol))
     {
         default:    // EQUAL:
-        return UNDECIDED;
+        return Solution::UNDECIDED;
 
         case Terminal::SMALLER:             // shift precedence < prod. prec.
-        return REDUCE;
+        return Solution::REDUCE;
 
         case Terminal::LARGER:              // shift precedence > prod. prec.
-        return SHIFT;
+        return Solution::SHIFT;
     }
 }
