@@ -20,7 +20,13 @@ void Options::showFilenames() const
         "  Base class header:           `" << d_baseClassHeader << "'\n"
         "  Class header:                `" << d_classHeader << "'\n"
         "  Implementation header:       `" << d_implementationHeader << "'\n"
-        "  Parser Implementation:       `" << d_parsefunSource << "'\n"
+        "  Parser Implementation:       `" << d_parsefunSource << "'\n";
+
+    if (useTokenPath())
+        cout <<
+            "  Tokens defined in:           `" << d_tokenPath << "'\n";
+
+    cout << 
         "  Verbose grammar description: `" << d_verboseName << "'\n"
         "\n";
 }
