@@ -8,12 +8,6 @@ void Parser::handleProductionElement(STYPE_ &last)
     if (!d_rules.hasRules())    // may happen if the first rule could not be
         return;                 // defined because of token/rulename clash
 
-    if (not last.valid())        // the last PTag was a %prec specification
-    {
-        checkFirstType();
-        return;
-    }
-
     switch (last.tag())
     {
         case Tag_::TERMINAL:
@@ -28,6 +22,10 @@ void Parser::handleProductionElement(STYPE_ &last)
             installAction(last.get<Tag_::BLOCK>());
         break;
 
+        case Tag_::END_TAG_:
+            checkFirstType();
+        return;
+
         default:            // can't occur, but prevents a warning
         break;              // from the compiler
     }
