@@ -7,13 +7,12 @@ void Rules::augmentGrammar(Symbol *start)
 {
     string augment = start->name() + "_$";
 
-    addRule(insert(new NonTerminal(augment)));
-    addProduction();
+    newRule(insert(new NonTerminal(augment)), "-N.A.-", 0);
+    addProduction(0);
 
     s_acceptProductionNr = d_currentProduction->nr();
     s_startSymbol = start;
 
     addElement(start);
-    d_currentRule->setEOFinFollow();
     d_currentRule->used();
 }
