@@ -1,6 +1,6 @@
-    #include "rules.ih"
+#include "rules.ih"
     
-bool Rules::newRule(NonTerminal *np, string const &source, size_t line)
+bool Rules::newRule(NonTerminal *np, string const &source, size_t lineNr)
 {
 // If the terminal definition is really requested (it isn't shown in bisonc++
 // 2.8.0) then pass yylineno from parser/openrule.cc and
@@ -11,6 +11,10 @@ bool Rules::newRule(NonTerminal *np, string const &source, size_t line)
 //  imsg.setLineNr(lineNr);
 //  imsg << "Adding production rule for `" << np->name() << "'" << endl;
 
+    s_lastLineNr = lineNr;
+
+    Production::storeFilename(source);
+
     if (!d_startRule.length())
         d_startRule = np->name();
 
@@ -20,6 +24,6 @@ bool Rules::newRule(NonTerminal *np, string const &source, size_t line)
     if (nfIter != d_location.end())
         return false;                   // extending an existing rulename
 
-    d_location[np] = FileInfo(source, line);
+    d_location[np] = FileInfo(source, lineNr);
     return true;
 }
