@@ -1,10 +1,19 @@
 #include "rules.ih"
 
-void Rules::updatePrecedence(Production *production, 
-                             Terminal::Vector const &tv)
+void Rules::updatePrecedence(Production *production)
 {   
     if (production->precedence())       // a precedence has already been set
-    {
+        return;
+
+    auto symbolIter = 
+        find_if(production->begin(), production->end(), isTerminal);
+
+    if (symbolIter != production->end())
+        production->setPrecedence(Terminal::downcast(*symbolIter));
+}
+
+//  elaborate compound stmnt after if (production->precedence):
+//    {
 //        if 
 //        (
 //            not (*production)[0].isTerminal() 
@@ -21,14 +30,13 @@ void Rules::updatePrecedence(Production *production,
 //                    ": 1st element must be a terminal token, 2nd "
 //                    "element a non-terminal token" << endl;
 //        }
+//        return;
+//    }
+
+
+
+
 
-        return;
-    }
 
-    auto symbolIter = 
-        find_if(production->begin(), production->end(), isTerminal);
 
-    if (symbolIter != production->end())
-        production->setPrecedence(Terminal::downcast(*symbolIter));
-}
 
