@@ -6,13 +6,7 @@ $insert scanner.h
 
 $insert namespace-open
 
-#undef \@
-    // CAVEAT: between the baseclass-include directive and the 
-    // #undef directive in the previous line references to \@ 
-    // are read as \@Base.
-    // If you need to include additional headers in this file 
-    // you should do so after these comment-lines.
-
+$insert undefparser
 
 class \@: public \@Base
 {
