@@ -6,5 +6,7 @@ SRConflict::SRConflict(Next::Vector const &nextVector,
 :
     d_nextVector(nextVector),
     d_itemVector(itemVector),
-    d_reducible(reducible)   
+    d_reducible(reducible), 
+    d_lastItemIdx(numeric_limits<size_t>::max()),
+    d_lastNext(numeric_limits<size_t>::max())
 {}
