@@ -3,8 +3,8 @@
 void Terminal::setValue(size_t value)
 {
     if (!setUnique(value))                
-        msg() << "Value " << value << " of token " << this << 
-                     " multiply assigned " << err;
+        emsg << "Value " << value << " of token " << this << 
+                     " multiply assigned " << endl;
     
     s_valueSet.erase(d_value);
     s_value = value + 1;
