@@ -3,8 +3,8 @@
 void Writer::symbolicNames() const
 {
     *d_out <<  
-        "typedef std::unordered_map<int, char const *> SMap;\n"
-        "typedef SMap::value_type SMapVal;\n"
+        "using SMap = std::unordered_map<int, char const *>;\n"
+        "using SMapVal = SMap::value_type;\n"
         "\n"
         "SMapVal s_symArr[] =\n"
         "{\n"
